# utils-py
![ci-badge](https://github.com/outcome-co/utils-py/workflows/Release/badge.svg?branch=v4.8.1) ![version-badge](https://img.shields.io/badge/version-4.8.1-brightgreen)

A set of python utilities.

## Usage

```sh
poetry add outcome-utils
```

## Development

Remember to run `./pre-commit.sh` when you clone the repository.
